@@ -53,7 +53,7 @@ enum {
 };
 
 static void
-gupnp_didl_lite_container_init (GUPnPDIDLLiteContainer *container)
+gupnp_didl_lite_container_init (G_GNUC_UNUSED GUPnPDIDLLiteContainer *container)
 {
         /* Nothing to initialize, yay! */
 }
@@ -367,7 +367,7 @@ gupnp_didl_lite_container_get_total_deleted_child_count
 
         return xml_util_get_uint_child_element (xml_node,
                                                 "totalDeletedChildCount",
-                                                0);
+                                                -1);
 }
 
 /**
