@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -46,34 +46,34 @@ gupnp_search_criteria_op_get_type (void)
                 static const GEnumValue values[] = {
                         { GUPNP_SEARCH_CRITERIA_OP_EQ,
                           "GUPNP_SEARCH_CRITERIA_OP_EQ",
-                          "none" },
+                          "EQ" },
                         { GUPNP_SEARCH_CRITERIA_OP_NEQ,
                           "GUPNP_SEARCH_CRITERIA_OP_NEQ",
-                          "none" },
+                          "NEQ" },
                         { GUPNP_SEARCH_CRITERIA_OP_LESS,
                           "GUPNP_SEARCH_CRITERIA_OP_LESS",
-                          "none" },
+                          "LESS" },
                         { GUPNP_SEARCH_CRITERIA_OP_LEQ,
                           "GUPNP_SEARCH_CRITERIA_OP_LEQ",
-                          "none" },
+                          "LEQ" },
                         { GUPNP_SEARCH_CRITERIA_OP_GREATER,
                           "GUPNP_SEARCH_CRITERIA_OP_GREATER",
-                          "none" },
+                          "GREATER" },
                         { GUPNP_SEARCH_CRITERIA_OP_GEQ,
                           "GUPNP_SEARCH_CRITERIA_OP_GEQ",
-                          "none" },
+                          "GEQ" },
                         { GUPNP_SEARCH_CRITERIA_OP_CONTAINS,
                           "GUPNP_SEARCH_CRITERIA_OP_CONTAINS",
-                          "none" },
+                          "CONTAINS" },
                         { GUPNP_SEARCH_CRITERIA_OP_DOES_NOT_CONTAIN,
                           "GUPNP_SEARCH_CRITERIA_OP_DOES_NOT_CONTAIN",
-                          "none" },
+                          "DOES_NOT_CONTAIN" },
                         { GUPNP_SEARCH_CRITERIA_OP_DERIVED_FROM,
                           "GUPNP_SEARCH_CRITERIA_OP_DERIVED_FROM",
-                          "none" },
+                          "DERIVED_FROM" },
                         { GUPNP_SEARCH_CRITERIA_OP_EXISTS,
                           "GUPNP_SEARCH_CRITERIA_OP_EXISTS",
-                          "none" },
+                          "EXISTS" },
                         { 0, NULL, NULL }
                 };
 
